@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2011-2012, 2014 Rocky Bernstein <rocky@cpan.org>
+# Copyright (C) 2011-2012, 2014-2015 Rocky Bernstein <rocky@cpan.org>
 # Interface when communicating with the user.
 
 use warnings; no warnings 'redefine';
@@ -60,8 +60,13 @@ sub add_history($$)
     my ($self, $command) = @_;
     return unless ($self->{input}{readline});
     $self->{input}{readline}->add_history($command) ;
-    my $now = localtime;
-    $self->{input}{readline}->add_history_time($now);
+
+    # my $now = localtime;
+    # $self->{input}{readline}->add_history_time($now);
+
+    # Having problems with setting destroy to write history.
+    # So write it after each add. Ugh.
+    $self->{input}{readline}->write_history($self->{histfile}, $command);
 }
 
 sub remove_history($;$)
@@ -130,30 +135,6 @@ sub read_history($)
     }
 }
 
-sub save_history($)
-{
-    my $self = shift;
-    if ($self->{histfile} && $self->{opts}{history_save} &&
-        $self->want_term_readline &&
-        $self->{input}{readline}) {
-
-        $self->{input}{readline}->StifleHistory($self->{histsize}) if
-            $self->{input}{readline}->can("StifleHistory");
-	if ($self->{input}{readline}->can("WriteHistory")) {
-	    $self->{input}{readline}->WriteHistory($self->{histfile})
-	}
-    }
-}
-
-# sub DESTROY($)
-# {
-#     my $self = shift;
-#     if ($self->want_term_readline) {
-#       $self->save_history;
-#     }
-#     Devel::Trepan::Interface::DESTROY($self);
-# }
-
 sub is_interactive($)
 {
     my $self = shift;
